// Libs
import {atom, urlParams, FontLoader, Config, L10n} from 'playable-ads-libs';

// Fonts
import fontGudeaRegular from '../fonts/Gudea-Regular.otf';

// Images
import imgBgMain from '../images/bg_main.jpg';
import imgWatermark from '../images/is_watermark.png';
import imgSpinner from '../images/spinner.png';
import imgLogo from '../images/logo.png';

export default class Boot extends Phaser.State {
  preload() {
    atom.adStarted();

    // Load fonts
    FontLoader.load(fontGudeaRegular, 'GudeaRegular', 'opentype');

    // Assign config & localization to game
    this.game.config = new Config(urlParams.config);
    this.game.l10n = new L10n(this.game.config.loc || urlParams.loc);

    // Game settings
    this.game.input.maxPointers = 1;
    this.game.scale.pageAlignHorizontally = true;
    this.game.scale.scaleMode = Phaser.ScaleManager.SHOW_ALL;
    this.game.scale.fullScreenScaleMode = Phaser.ScaleManager.SHOW_ALL;
    this.game.stage.disableVisibilityChange = true;

    // Init global variables
    this.game.score = 0;

    // Preload images
    this.game.load.image('bg_main', imgBgMain);
    this.game.load.image('is_watermark', imgWatermark);
    this.game.load.image('spinner', imgSpinner);
    this.game.load.image('logo', imgLogo);

    // When images loading is complete - init config & localization
    this.load.onLoadComplete.addOnce(() => {
      // Draw screen to  show fake loading
      this.drawScreen();

      // Show game after X seconds
      setTimeout(() => this.game.state.start('game'), 1000);
    }, this);
  }

  drawScreen() {
    atom.loading();

    this.game.stage.backgroundColor = '#000000';

    const logo = this.game.add.sprite(this.game.world.centerX, this.game.world.centerY, 'logo');
    logo.anchor.setTo(0.5);

    const spinner = this.game.add.sprite(this.game.world.centerX, this.game.world.centerY + 100, 'spinner');
    spinner.anchor.setTo(0.5);
    this.game.add.tween(spinner).to({angle: 360}, 1000, Phaser.Easing.Linear.None, true, false, false);
  }
}
